@@ -150,7 +150,7 @@ class POI(BaseModel):
 class TableResponse(Response):
     sources: List[POI] = []
     destinations: List[POI] = []
-    durations: List[List[float]] = []
+    durations: List[List[int]] = []
     distances: List[List[float]] = []
 
     @classmethod
